@@ -8,11 +8,6 @@
 #include "CCM.h"
 #include "Multiview.h"
 
-
-// CS: Note to ask JP: Set validLib parameter at bottom of existing signatures
-// to avoid bloated overloads, but semantically it belongs before verbose. Both
-// seem valid to me, but I understand if you opt for the latter.
-
 //-------------------------------------------------------------
 // API function declarations.
 //
@@ -44,40 +39,44 @@ DataFrame< double > MakeBlock( DataFrame< double >      & dataFrame,
                                std::vector<std::string> columnNames,
                                bool                     deletePartial = false );
 
-DataFrame< double > Simplex( std::string pathIn          = "./data/",
-                             std::string dataFile        = "",
-                             std::string pathOut         = "./",
-                             std::string predictFile     = "",
-                             std::string lib             = "",
-                             std::string pred            = "",
-                             int         E               = 0,
-                             int         Tp              = 1,
-                             int         knn             = 0,
-                             int         tau             = -1,
-                             int         exclusionRadius = 0,
-                             std::string colNames        = "",
-                             std::string targetName      = "",
-                             bool        embedded        = false,
-                             bool        const_predict   = false,
-                             bool        verbose         = true,
-                             std::vector<bool> validLib  = std::vector<bool>() );
+SimplexValues Simplex( std::string pathIn          = "./data/",
+                       std::string dataFile        = "",
+                       std::string pathOut         = "./",
+                       std::string predictFile     = "",
+                       std::string lib             = "",
+                       std::string pred            = "",
+                       int         E               = 0,
+                       int         Tp              = 1,
+                       int         knn             = 0,
+                       int         tau             = -1,
+                       int         exclusionRadius = 0,
+                       std::string colNames        = "",
+                       std::string targetName      = "",
+                       bool        embedded        = false,
+                       bool        const_predict   = false,
+                       bool        verbose         = true,
+                       std::vector<bool> validLib  = std::vector<bool>(),
+                       int         generateSteps   = 0,
+                       bool        parameterList   = false );
 
-DataFrame< double > Simplex( DataFrame< double > & dataFrameIn,
-                             std::string pathOut         = "./",
-                             std::string predictFile     = "",
-                             std::string lib             = "",
-                             std::string pred            = "",
-                             int         E               = 0,
-                             int         Tp              = 1,
-                             int         knn             = 0,
-                             int         tau             = -1,
-                             int         exclusionRadius = 0,
-                             std::string colNames        = "",
-                             std::string targetName      = "",
-                             bool        embedded        = false,
-                             bool        const_predict   = false,
-                             bool        verbose         = true,
-                             std::vector<bool> validLib  = std::vector<bool>());
+SimplexValues Simplex( DataFrame< double > & dataFrameIn,
+                       std::string pathOut         = "./",
+                       std::string predictFile     = "",
+                       std::string lib             = "",
+                       std::string pred            = "",
+                       int         E               = 0,
+                       int         Tp              = 1,
+                       int         knn             = 0,
+                       int         tau             = -1,
+                       int         exclusionRadius = 0,
+                       std::string colNames        = "",
+                       std::string targetName      = "",
+                       bool        embedded        = false,
+                       bool        const_predict   = false,
+                       bool        verbose         = true,
+                       std::vector<bool> validLib  = std::vector<bool>(),
+                       int         generateSteps   = 0,
+                       bool        parameterList   = false );
 
 // SMap is a special case since it can be called with a function pointer
 // to the SVD solver. This is done so that interfaces such as pybind11
@@ -102,7 +101,9 @@ SMapValues SMap( std::string pathIn          = "./data/",
                  bool        embedded        = false,
                  bool        const_predict   = false,
                  bool        verbose         = true,
-                 std::vector<bool> validLib  = std::vector<bool>() );
+                 std::vector<bool> validLib  = std::vector<bool>(),
+                 int         generateSteps   = 0,
+                 bool        parameterList   = false );
 
 // 2) DataFrame with default SVD (LAPACK) assigned in Smap.cc 2)
 SMapValues SMap( DataFrame< double > &dataFrameIn,
@@ -123,7 +124,9 @@ SMapValues SMap( DataFrame< double > &dataFrameIn,
                  bool        embedded        = false,
                  bool        const_predict   = false,
                  bool        verbose         = true,
-                 std::vector<bool> validLib  = std::vector<bool>() );
+                 std::vector<bool> validLib  = std::vector<bool>(),
+                 int         generateSteps   = 0,
+                 bool        parameterList   = false );
 
 // 3) Data path/file with external solver object, init to default SVD
 SMapValues SMap( std::string pathIn          = "./data/",
@@ -148,7 +151,9 @@ SMapValues SMap( std::string pathIn          = "./data/",
                  bool        embedded        = false,
                  bool        const_predict   = false,
                  bool        verbose         = true,
-                 std::vector<bool> validLib  = std::vector<bool>() );
+                 std::vector<bool> validLib  = std::vector<bool>(),
+                 int         generateSteps   = 0,
+                 bool        parameterList   = false );
 
 
 // 4) DataFrame with external solver object, init to default SVD
@@ -173,7 +178,9 @@ SMapValues SMap( DataFrame< double > &dataFrameIn,
                  bool        embedded        = false,
                  bool        const_predict   = false,
                  bool        verbose         = true,
-                 std::vector<bool> validLib  = std::vector<bool>() );
+                 std::vector<bool> validLib  = std::vector<bool>(),
+                 int         generateSteps   = 0,
+                 bool        parameterList   = false );
 
 CCMValues CCM( std::string pathIn          = "./data/",
                std::string dataFile        = "",
@@ -192,6 +199,7 @@ CCMValues CCM( std::string pathIn          = "./data/",
                bool        replacement     = false,
                unsigned    seed            = 0,     // seed=0: use RNG
                bool        includeData     = false,
+               bool        parameterList   = false,
                bool        verbose         = true );
 
 CCMValues CCM( DataFrame< double > & dataFrameIn,
@@ -210,6 +218,7 @@ CCMValues CCM( DataFrame< double > & dataFrameIn,
                bool        replacement     = false,
                unsigned    seed            = 0, // seed=0: use RNG
                bool        includeData     = false,
+               bool        parameterList   = false,
                bool        verbose         = true );
 
 MultiviewValues Multiview( std::string pathIn          = "./",
@@ -229,6 +238,7 @@ MultiviewValues Multiview( std::string pathIn          = "./",
                            int         exclusionRadius = 0,
                            bool        trainLib        = true,
                            bool        excludeTarget   = false,
+                           bool        parameterList   = false,
                            bool        verbose         = false,
                            unsigned    nThreads        = 4 );
 
@@ -248,97 +258,98 @@ MultiviewValues Multiview( DataFrame< double > & dataFrameIn,
                            int         exclusionRadius = 0,
                            bool        trainLib        = true,
                            bool        excludeTarget   = false,
+                           bool        parameterList   = false,
                            bool        verbose         = false,
                            unsigned    nThreads        = 4 );
 
-DataFrame< double > EmbedDimension( std::string pathIn      = "./data/",
-                                    std::string dataFile    = "",
-                                    std::string pathOut     = "./",
-                                    std::string predictFile = "",
-                                    std::string lib         = "",
-                                    std::string pred        = "",
-                                    int         maxE        = 10,
-                                    int         Tp          = 1,
-                                    int         tau         = -1,
-                                    std::string colNames    = "",
-                                    std::string targetName  = "",
-                                    bool        embedded    = false,
-                                    bool        verbose     = true,
-                                    unsigned    nThreads    = 4 );
+DataFrame< double > EmbedDimension( std::string pathIn        = "./data/",
+                                    std::string dataFile      = "",
+                                    std::string pathOut       = "./",
+                                    std::string predictFile   = "",
+                                    std::string lib           = "",
+                                    std::string pred          = "",
+                                    int         maxE          = 10,
+                                    int         Tp            = 1,
+                                    int         tau           = -1,
+                                    std::string colNames      = "",
+                                    std::string targetName    = "",
+                                    bool        embedded      = false,
+                                    bool        verbose       = true,
+                                    unsigned    nThreads      = 4 );
 
 DataFrame< double > EmbedDimension( DataFrame< double > & dataFrameIn,
-                                    std::string pathOut     = "./",
-                                    std::string predictFile = "",
-                                    std::string lib         = "",
-                                    std::string pred        = "",
-                                    int         maxE        = 10,
-                                    int         Tp          = 1,
-                                    int         tau         = -1,
-                                    std::string colNames    = "",
-                                    std::string targetName  = "",
-                                    bool        embedded    = false,
-                                    bool        verbose     = true,
-                                    unsigned    nThreads    = 4 );
+                                    std::string pathOut       = "./",
+                                    std::string predictFile   = "",
+                                    std::string lib           = "",
+                                    std::string pred          = "",
+                                    int         maxE          = 10,
+                                    int         Tp            = 1,
+                                    int         tau           = -1,
+                                    std::string colNames      = "",
+                                    std::string targetName    = "",
+                                    bool        embedded      = false,
+                                    bool        verbose       = true,
+                                    unsigned    nThreads      = 4 );
 
-DataFrame< double > PredictInterval( std::string pathIn      = "./data/",
-                                     std::string dataFile    = "",
-                                     std::string pathOut     = "./",
-                                     std::string predictFile = "",
-                                     std::string lib         = "",
-                                     std::string pred        = "",
-                                     int         maxTp       = 10,
-                                     int         E           = 0,
-                                     int         tau         = -1,
-                                     std::string colNames    = "",
-                                     std::string targetName  = "",
-                                     bool        embedded    = false,
-                                     bool        verbose     = true,
-                                     unsigned    nThreads    = 4 );
+DataFrame< double > PredictInterval( std::string pathIn        = "./data/",
+                                     std::string dataFile      = "",
+                                     std::string pathOut       = "./",
+                                     std::string predictFile   = "",
+                                     std::string lib           = "",
+                                     std::string pred          = "",
+                                     int         maxTp         = 10,
+                                     int         E             = 0,
+                                     int         tau           = -1,
+                                     std::string colNames      = "",
+                                     std::string targetName    = "",
+                                     bool        embedded      = false,
+                                     bool        verbose       = true,
+                                     unsigned    nThreads      = 4 );
 
 DataFrame< double > PredictInterval( DataFrame< double > & dataFrameIn,
-                                     std::string pathOut     = "./",
-                                     std::string predictFile = "",
-                                     std::string lib         = "",
-                                     std::string pred        = "",
-                                     int         maxTp       = 10,
-                                     int         E           = 0,
-                                     int         tau         = -1,
-                                     std::string colNames    = "",
-                                     std::string targetName  = "",
-                                     bool        embedded    = false,
-                                     bool        verbose     = true,
-                                     unsigned    nThreads    = 4 );
+                                     std::string pathOut       = "./",
+                                     std::string predictFile   = "",
+                                     std::string lib           = "",
+                                     std::string pred          = "",
+                                     int         maxTp         = 10,
+                                     int         E             = 0,
+                                     int         tau           = -1,
+                                     std::string colNames      = "",
+                                     std::string targetName    = "",
+                                     bool        embedded      = false,
+                                     bool        verbose       = true,
+                                     unsigned    nThreads      = 4 );
 
-DataFrame< double > PredictNonlinear( std::string pathIn      = "./data/",
-                                      std::string dataFile    = "",
-                                      std::string pathOut     = "./",
-                                      std::string predictFile = "",
-                                      std::string lib         = "",
-                                      std::string pred        = "",
-                                      std::string theta       = "",
-                                      int         E           = 0,
-                                      int         Tp          = 1,
-                                      int         knn         = 0,
-                                      int         tau         = -1,
-                                      std::string colNames    = "",
-                                      std::string targetName  = "",
-                                      bool        embedded    = false,
-                                      bool        verbose     = true,
-                                      unsigned    nThreads    = 4 );
+DataFrame< double > PredictNonlinear( std::string pathIn        = "./data/",
+                                      std::string dataFile      = "",
+                                      std::string pathOut       = "./",
+                                      std::string predictFile   = "",
+                                      std::string lib           = "",
+                                      std::string pred          = "",
+                                      std::string theta         = "",
+                                      int         E             = 0,
+                                      int         Tp            = 1,
+                                      int         knn           = 0,
+                                      int         tau           = -1,
+                                      std::string colNames      = "",
+                                      std::string targetName    = "",
+                                      bool        embedded      = false,
+                                      bool        verbose       = true,
+                                      unsigned    nThreads      = 4 );
 
 DataFrame< double > PredictNonlinear( DataFrame< double > & dataFrameIn,
-                                      std::string pathOut     = "./",
-                                      std::string predictFile = "",
-                                      std::string lib         = "",
-                                      std::string pred        = "",
-                                      std::string theta       = "",
-                                      int         E           = 0,
-                                      int         Tp          = 1,
-                                      int         knn         = 0,
-                                      int         tau         = -1,
-                                      std::string colNames    = "",
-                                      std::string targetName  = "",
-                                      bool        embedded    = false,
-                                      bool        verbose     = true,
-                                      unsigned    nThreads    = 4 );
+                                      std::string pathOut       = "./",
+                                      std::string predictFile   = "",
+                                      std::string lib           = "",
+                                      std::string pred          = "",
+                                      std::string theta         = "",
+                                      int         E             = 0,
+                                      int         Tp            = 1,
+                                      int         knn           = 0,
+                                      int         tau           = -1,
+                                      std::string colNames      = "",
+                                      std::string targetName    = "",
+                                      bool        embedded      = false,
+                                      bool        verbose       = true,
+                                      unsigned    nThreads      = 4 );
 #endif
